**Example 1: 终止任务批次**



Input: 

```
tccli omics TerminateRunGroup --cli-unfold-argument  \
    --RunGroupId run-greedy-cerise-swan-618086 \
    --ProjectId prj-zealous-black-seagull-241194
```

Output: 
```
{
    "Response": {
        "RequestId": "67d1c8b8-1f8f-4c24-acac-7194409a0a25"
    }
}
```

